package data.missions.HA_battleforjanusprime;

import java.util.List;

import com.fs.starfarer.api.combat.BaseEveryFrameCombatPlugin;
import com.fs.starfarer.api.combat.CombatEngineAPI;
import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		
		// Set up the fleets so we can add ships and fighter wings to them.
		// In this scenario, the fleets are attacking each other, but
		// in other scenarios, a fleet may be defending or trying to escape
		api.initFleet(FleetSide.PLAYER, "ISS", FleetGoal.ATTACK, false, 3);
		api.initFleet(FleetSide.ENEMY, "HSS", FleetGoal.ATTACK, true);

		// Set a small blurb for each fleet that shows up on the mission detail and
		// mission results screens to identify each side.
		api.setFleetTagline(FleetSide.PLAYER, "Small Tri-tachyon fleet under the command of Orbon Cyr");
		api.setFleetTagline(FleetSide.ENEMY, "Pirate Pillaging Force");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		api.addBriefingItem("Defeat the pirates");
		api.addBriefingItem("Don't loose the 'ISS Greenwich'");
		api.addBriefingItem("You don't have many ships, use guerilla tactics to defeat your opponent");
		
		// Set up the player's fleet.  Variant names come from the
		// files in data/variants and data/variants/fighters
		//api.addToFleet(FleetSide.PLAYER, "harbinger_Strike", FleetMemberType.SHIP, "TTS Invisible Hand", true, CrewXPLevel.VETERAN);
		
		api.addToFleet(FleetSide.PLAYER, "HA_Caltrop_beamer", FleetMemberType.SHIP, "ISS Greenwich", true);
		api.addToFleet(FleetSide.PLAYER, "HA_Corprus_escort", FleetMemberType.SHIP, "ISS Northhampton", false);
		api.addToFleet(FleetSide.PLAYER, "HA_Colchester_beamer", FleetMemberType.SHIP, "ISS Oxford", false);
		api.addToFleet(FleetSide.PLAYER, "HA_Effigy_antifighter", FleetMemberType.SHIP, "ISS Ippswitch", false);
		


		api.defeatOnShipLoss("ISS Greenwich");
		
		// Set up the enemy fleet.
		//api.addToFleet(FleetSide.ENEMY, "mule_Standard", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "tarsus_Standard", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "buffalo2_FS", FleetMemberType.SHIP, false);

		api.addToFleet(FleetSide.ENEMY, "dominator_d_Assault", FleetMemberType.SHIP, "HSS Butcher's Cleaver", false);	
		api.addToFleet(FleetSide.ENEMY, "dominator_d_Assault", FleetMemberType.SHIP, "HSS Warrior's Knife", false);	
		api.addToFleet(FleetSide.ENEMY, "dominator_d_Assault", FleetMemberType.SHIP, "HSS Scientist's Screwdriver", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_d_pirates_Strike", FleetMemberType.SHIP, "HSS 'Murica Smeg Yeah!", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_d_pirates_Strike", FleetMemberType.SHIP, "HSS 'Murica Smeg No!", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_d_pirates_Strike", FleetMemberType.SHIP, "HSS 'Murica Smeg Maybe!", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_d_Strike", FleetMemberType.SHIP, "HSS Don't Touch The Baby", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_Overdriven", FleetMemberType.SHIP, "HSS A Really Ugly Duckling", false);
		api.addToFleet(FleetSide.ENEMY, "enforcer_Overdriven", FleetMemberType.SHIP, "HSS A Really Pretty Goose", false);
		api.addToFleet(FleetSide.ENEMY, "lasher_d_CS", FleetMemberType.SHIP, "HSS Fire The Lack-Of Missiles!", false);
		api.addToFleet(FleetSide.ENEMY, "lasher_d_CS", FleetMemberType.SHIP, "HSS The Green Eater", false);
		api.addToFleet(FleetSide.ENEMY, "lasher_d_CS", FleetMemberType.SHIP, "HSS Dead Empowerment", false);

	
		
		// Set up the map.
		float width = 24000f;
		float height = 18000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;
		
		api.addNebula(minX + width * 0.5f - 300, minY + height * 0.5f, 1000);
		api.addNebula(minX + width * 0.5f + 300, minY + height * 0.5f, 1000);
		
		for (int i = 0; i < 5; i++) {
			float x = (float) Math.random() * width - width/2;
			float y = (float) Math.random() * height - height/2;
			float radius = 100f + (float) Math.random() * 400f; 
			api.addNebula(x, y, radius);
		}
		
		// Add an asteroid field
		api.addAsteroidField(minX + width/2f, minY + height/2f, 0, 8000f,
								20f, 70f, 100);
		
		api.addPlugin(new BaseEveryFrameCombatPlugin() {
			public void init(CombatEngineAPI engine) {
				engine.getContext().setStandoffRange(6000f);
			}
			public void advance(float amount, List events) {
			}
		});
		
	}

}




